@@ -1,6 +1,6 @@
 package Catmandu::DirectoryIndex::Number;
 
-our $VERSION = '1.10';
+our $VERSION = '1.11';
 
 use Catmandu::Sane;
 use Catmandu::Util qw(:is :check);
@@ -146,6 +146,9 @@ sub generator {
 
         return unless defined $path;
 
+        #Path::Iterator::Rule hardcodes forward slashes
+        $path =~ s/\//\\/go if $^O eq "MSWin32";
+
         my $id = $self->_from_path($path);
 
         +{_id => $id, _path => $path};
