@@ -1,6 +1,6 @@
 package Catmandu::DirectoryIndex::UUID;
 
-our $VERSION = '1.10';
+our $VERSION = '1.11';
 
 use Catmandu::Sane;
 use Catmandu::Util qw(:is :check);
@@ -138,6 +138,9 @@ sub generator {
 
         return unless defined $path;
 
+        #Path::Iterator::Rule hardcodes forward slashes
+        $path =~ s/\//\\/go if $^O eq "MSWin32";
+
 #TODO: does not throw an error when directory is less than 12 levels (because no directories are validated)
         my $id = $self->_from_path($path);
 
